@@ -1,8 +1,21 @@
 use crate::tap_error::Result;
 use crate::{
-    BasicNodeType, DatatypeId, NodeType, PlaceholderResolver, PropertyId, ReaderRange, ShapeId,
-    TapConfig, TapError, TapReaderState, TapReaderWarning, TapShape, TapStatement, Value,
-    ValueConstraint, ValueConstraintType,
+    BasicNodeType,
+    DatatypeId,
+    NodeType,
+    PlaceholderResolver,
+    PropertyId,
+    // ReaderRange,
+    ShapeId,
+    TapConfig,
+    TapError,
+    TapReaderState,
+    TapReaderWarning,
+    TapShape,
+    TapStatement,
+    Value,
+    ValueConstraint,
+    ValueConstraintType,
 };
 use csv::{Position, Reader as CsvReader, StringRecord};
 use tracing::debug;
@@ -11,7 +24,7 @@ use std::io::{self};
 
 enum StringRecordReader<R> {
     CsvReader(CsvReader<R>),
-    RangeReader(ReaderRange<R>),
+    // RangeReader(ReaderRange<R>),
 }
 
 impl<R: io::Read> StringRecordReader<R> {
@@ -19,31 +32,30 @@ impl<R: io::Read> StringRecordReader<R> {
         StringRecordReader::CsvReader(reader)
     }
 
-    pub fn new_range_reader(range: ReaderRange<R>) -> StringRecordReader<R> {
+    /*pub fn new_range_reader(range: ReaderRange<R>) -> StringRecordReader<R> {
         StringRecordReader::RangeReader(range)
-    }
+    }*/
 
     pub fn read_record(&mut self, record: &mut StringRecord) -> Result<bool> {
         match self {
             StringRecordReader::CsvReader(reader) => {
                 let b = reader.read_record(record)?;
                 Ok(b)
-            }
-            StringRecordReader::RangeReader(reader_range) => {
-                if let Some(rcd) = reader_range.next_record() {
-                    *record = rcd;
-                    Ok(true)
-                } else {
-                    Ok(false)
-                }
-            }
+            } /*StringRecordReader::RangeReader(reader_range) => {
+                  if let Some(rcd) = reader_range.next_record() {
+                      *record = rcd;
+                      Ok(true)
+                  } else {
+                      Ok(false)
+                  }
+              }*/
         }
     }
 
     pub fn position(&mut self) -> &Position {
         match self {
             StringRecordReader::CsvReader(reader) => reader.position(),
-            StringRecordReader::RangeReader(range) => range.position(),
+            // StringRecordReader::RangeReader(range) => range.position(),
         }
     }
 }
@@ -63,7 +75,7 @@ impl<R: io::Read> TapReader<R> {
         }
     }
 
-    pub fn new_range_reader(
+    /*pub fn new_range_reader(
         reader: ReaderRange<R>,
         state: TapReaderState,
         config: &TapConfig,
@@ -73,7 +85,7 @@ impl<R: io::Read> TapReader<R> {
             state,
             config: config.clone(),
         }
-    }
+    }*/
 
     pub fn shapes(&mut self) -> ShapesIter<R> {
         ShapesIter::new(self)
