@@ -62,9 +62,9 @@ impl IriS {
     pub fn extend(&self, str: &str) -> Result<Self, IriSError> {
         let current_str = self.iri.as_str();
         let extended_str = if current_str.ends_with('/') || current_str.ends_with('#') {
-            format!("{}{}", current_str, str)
+            format!("{current_str}{str}")
         } else {
-            format!("{}/{}", current_str, str)
+            format!("{current_str}/{str}")
         };
         let iri = NamedNode::new(extended_str.as_str()).map_err(|e| IriSError::IriParseError {
             str: extended_str,
@@ -204,6 +204,12 @@ impl Serialize for IriS {
     }
 }
 
+impl From<NamedNode> for IriS {
+    fn from(iri: NamedNode) -> Self {
+        IriS { iri }
+    }
+}
+
 impl FromStr for IriS {
     type Err = IriSError;
 
