@@ -656,6 +656,9 @@ pub enum Command {
 
         #[arg(short = 'x', long = "export-mode", value_name = "Result mode")]
         output_mode: OutputConvertMode,
+
+        #[arg(long = "show-time")]
+        show_time: Option<bool>,
     },
 
     /// Show information about SPARQL service
@@ -1051,6 +1054,7 @@ pub enum OutputConvertMode {
     ShEx,
     UML,
     HTML,
+    SHACL,
 }
 
 impl Display for OutputConvertMode {
@@ -1060,6 +1064,7 @@ impl Display for OutputConvertMode {
             OutputConvertMode::ShEx => write!(dest, "shex"),
             OutputConvertMode::UML => write!(dest, "uml"),
             OutputConvertMode::HTML => write!(dest, "html"),
+            OutputConvertMode::SHACL => write!(dest, "shacl"),
         }
     }
 }
