@@ -1,17 +1,19 @@
-use crate::{
-    component::Component, message_map::MessageMap, severity::Severity, target::Target, SH_CLOSED,
-    SH_DEACTIVATED, SH_DESCRIPTION, SH_GROUP, SH_INFO_STR, SH_NAME, SH_NODE_SHAPE, SH_PROPERTY,
-    SH_SEVERITY, SH_VIOLATION_STR, SH_WARNING_STR,
+use crate::shacl_vocab::{
+    sh_closed, sh_deactivated, sh_description, sh_group, sh_info, sh_name, sh_node_shape,
+    sh_property, sh_severity, sh_violation, sh_warning,
 };
-use iri_s::iri;
-use srdf::{RDFNode, SRDFBuilder};
+use crate::{component::Component, message_map::MessageMap, severity::Severity, target::Target};
+use srdf::{BuildRDF, RDFNode, Rdf};
 use std::fmt::Display;
 
-#[derive(Debug, Clone)]
-pub struct NodeShape {
+#[derive(Debug)]
+pub struct NodeShape<RDF: Rdf>
+where
+    RDF::Term: Clone,
+{
     id: RDFNode,
     components: Vec<Component>,
-    targets: Vec<Target>,
+    targets: Vec<Target<RDF>>,
     property_shapes: Vec<RDFNode>,
     closed: bool,
     // ignored_properties: Vec<IriRef>,
@@ -24,7 +26,7 @@ pub struct NodeShape {
     // source_iri: Option<IriRef>,
 }
 
-impl NodeShape {
+impl<RDF: Rdf> NodeShape<RDF> {
     pub fn new(id: RDFNode) -> Self {
         NodeShape {
             id,
@@ -43,12 +45,12 @@ impl NodeShape {
         }
     }
 
-    pub fn with_targets(mut self, targets: Vec<Target>) -> Self {
+    pub fn with_targets(mut self, targets: Vec<Target<RDF>>) -> Self {
         self.targets = targets;
         self
     }
 
-    pub fn set_targets(&mut self, targets: Vec<Target>) {
+    pub fn set_targets(&mut self, targets: Vec<Target<RDF>>) {
         self.targets = targets;
     }
 
@@ -87,7 +89,7 @@ impl NodeShape {
         &self.components
     }
 
-    pub fn targets(&self) -> &Vec<Target> {
+    pub fn targets(&self) -> &Vec<Target<RDF>> {
         &self.targets
     }
 
@@ -96,34 +98,27 @@ impl NodeShape {
     }
 
     // TODO: this is a bit ugly
-    pub fn write<RDF>(&self, rdf: &mut RDF) -> Result<(), RDF::Err>
+    pub fn write<B>(&self, rdf: &mut B) -> Result<(), B::Err>
     where
-        RDF: SRDFBuilder,
+        B: BuildRDF,
     {
-        rdf.add_type(&self.id.clone().into(), SH_NODE_SHAPE.clone().into())?;
+        let id: B::Subject = self.id.clone().try_into().map_err(|_| unreachable!())?;
+        rdf.add_type(id.clone(), sh_node_shape().clone())?;
 
         self.name.iter().try_for_each(|(lang, value)| {
-            let literal: RDF::Literal = match lang {
+            let literal: B::Literal = match lang {
                 Some(_) => todo!(),
                 None => value.clone().into(),
             };
-            rdf.add_triple(
-                &self.id.clone().try_into().map_err(|_| unreachable!())?,
-                &SH_NAME.clone().into(),
-                &literal.into(),
-            )
+            rdf.add_triple(id.clone(), sh_name().clone(), literal)
         })?;
 
         self.description.iter().try_for_each(|(lang, value)| {
-            let literal: RDF::Literal = match lang {
+            let literal: B::Literal = match lang {
                 Some(_) => todo!(),
                 None => value.clone().into(),
             };
-            rdf.add_triple(
-                &self.id.clone().try_into().map_err(|_| unreachable!())?,
-                &SH_DESCRIPTION.clone().into(),
-                &literal.into(),
-            )
+            rdf.add_triple(id.clone(), sh_description().clone(), literal)
         })?;
 
         self.components
@@ -135,61 +130,41 @@ impl NodeShape {
             .try_for_each(|target| target.write(&self.id, rdf))?;
 
         self.property_shapes.iter().try_for_each(|property_shape| {
-            rdf.add_triple(
-                &self.id.clone().try_into().map_err(|_| unreachable!())?,
-                &SH_PROPERTY.clone().into(),
-                &property_shape.clone().into(),
-            )
+            rdf.add_triple(id.clone(), sh_property().clone(), property_shape.clone())
         })?;
 
         if self.deactivated {
-            let literal: RDF::Literal = "true".to_string().into();
+            let literal: B::Literal = "true".to_string().into();
 
-            rdf.add_triple(
-                &self.id.clone().try_into().map_err(|_| unreachable!())?,
-                &SH_DEACTIVATED.clone().into(),
-                &literal.into(),
-            )?;
+            rdf.add_triple(id.clone(), sh_deactivated().clone(), literal)?;
         }
 
         if let Some(group) = &self.group {
-            rdf.add_triple(
-                &self.id.clone().try_into().map_err(|_| unreachable!())?,
-                &SH_GROUP.clone().into(),
-                &group.clone().into(),
-            )?;
+            rdf.add_triple(id.clone(), sh_group().clone(), group.clone())?;
         }
 
         if let Some(severity) = &self.severity {
             let pred = match severity {
-                Severity::Violation => iri!(SH_VIOLATION_STR),
-                Severity::Info => iri!(SH_INFO_STR),
-                Severity::Warning => iri!(SH_WARNING_STR),
+                Severity::Violation => sh_violation().clone(),
+                Severity::Info => sh_info().clone(),
+                Severity::Warning => sh_warning().clone(),
                 Severity::Generic(iri) => iri.get_iri().unwrap(),
             };
 
-            rdf.add_triple(
-                &self.id.clone().try_into().map_err(|_| unreachable!())?,
-                &SH_SEVERITY.clone().into(),
-                &pred.clone().into(),
-            )?;
+            rdf.add_triple(id.clone(), sh_severity().clone(), pred.clone())?;
         }
 
         if self.closed {
-            let literal: RDF::Literal = "true".to_string().into();
+            let literal: B::Literal = "true".to_string().into();
 
-            rdf.add_triple(
-                &self.id.clone().try_into().map_err(|_| unreachable!())?,
-                &SH_CLOSED.clone().into(),
-                &literal.into(),
-            )?;
+            rdf.add_triple(id.clone(), sh_closed().clone(), literal)?;
         }
 
         Ok(())
     }
 }
 
-impl Display for NodeShape {
+impl<RDF: Rdf> Display for NodeShape<RDF> {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         writeln!(f, "{{")?;
         if self.closed {
@@ -208,3 +183,35 @@ impl Display for NodeShape {
         Ok(())
     }
 }
+
+impl<RDF: Rdf> Clone for NodeShape<RDF> {
+    fn clone(&self) -> Self {
+        Self {
+            id: self.id.clone(),
+            components: self.components.clone(),
+            targets: self.targets.clone(),
+            property_shapes: self.property_shapes.clone(),
+            closed: self.closed,
+            deactivated: self.deactivated,
+            severity: self.severity.clone(),
+            name: self.name.clone(),
+            description: self.description.clone(),
+            group: self.group.clone(),
+        }
+    }
+}
+
+impl<RDF: Rdf> PartialEq for NodeShape<RDF> {
+    fn eq(&self, other: &Self) -> bool {
+        self.id == other.id
+            && self.components == other.components
+            && self.targets == other.targets
+            && self.property_shapes == other.property_shapes
+            && self.closed == other.closed
+            && self.deactivated == other.deactivated
+            && self.severity == other.severity
+            && self.name == other.name
+            && self.description == other.description
+            && self.group == other.group
+    }
+}
