@@ -10,6 +10,7 @@ where
     RDF: BuildRDF,
 {
     rdf: RDF,
+    shapes: isize,
 }
 
 impl<RDF> ShaclWriter<RDF>
@@ -17,7 +18,10 @@ where
     RDF: BuildRDF,
 {
     pub fn new() -> Self {
-        Self { rdf: RDF::empty() }
+        Self {
+            rdf: RDF::empty(),
+            shapes: 0,
+        }
     }
 
     pub fn write(&mut self, schema: &Schema<RDF>) -> Result<(), RDF::Err> {
@@ -29,13 +33,18 @@ where
         self.rdf.add_prefix_map(prefix_map)?;
         self.rdf.add_base(&schema.base())?;
 
-        schema
-            .iter()
-            .try_for_each(|(_, shape)| shape.write(&mut self.rdf))?;
+        schema.iter().try_for_each(|(_, shape)| {
+            self.shapes += 1;
+            shape.write(&mut self.rdf)
+        })?;
 
         Ok(())
     }
 
+    pub fn shapes_count(&self) -> isize {
+        self.shapes
+    }
+
     pub fn serialize<W: Write>(&self, format: &RDFFormat, writer: &mut W) -> Result<(), RDF::Err> {
         self.rdf.serialize(format, writer)
     }
