@@ -13,22 +13,25 @@ use crate::shape::Validate;
 use crate::validation_report::result::ValidationResult;
 use crate::value_nodes::ValueNodeIteration;
 use crate::value_nodes::ValueNodes;
-use shacl_ast::compiled::component::CompiledComponent;
-use shacl_ast::compiled::component::Or;
-use shacl_ast::compiled::shape::CompiledShape;
-use srdf::Query;
+use shacl_ir::compiled::component::CompiledComponent;
+use shacl_ir::compiled::component::Or;
+use shacl_ir::compiled::shape::CompiledShape;
+use srdf::NeighsRDF;
+use srdf::QueryRDF;
 use srdf::Rdf;
-use srdf::Sparql;
+use srdf::SHACLPath;
 use std::fmt::Debug;
 
-impl<S: Rdf + Debug> Validator<S> for Or<S> {
+impl<S: Rdf + Debug> Validator<S> for Or {
     fn validate(
         &self,
-        component: &CompiledComponent<S>,
-        shape: &CompiledShape<S>,
+        component: &CompiledComponent,
+        shape: &CompiledShape,
         store: &S,
         engine: impl Engine<S>,
         value_nodes: &ValueNodes<S>,
+        _source_shape: Option<&CompiledShape>,
+        maybe_path: Option<SHACLPath>,
     ) -> Result<Vec<ValidationResult>, ConstraintError> {
         let or = |value_node: &S::Term| {
             self.shapes()
@@ -38,6 +41,7 @@ impl<S: Rdf + Debug> Validator<S> for Or<S> {
                         store,
                         &engine,
                         Some(&FocusNodes::new(std::iter::once(value_node.clone()))),
+                        Some(shape),
                     ) {
                         Ok(validation_results) => validation_results.is_empty(),
                         Err(_) => false,
@@ -46,30 +50,59 @@ impl<S: Rdf + Debug> Validator<S> for Or<S> {
                 .not()
         };
 
-        validate_with(component, shape, value_nodes, ValueNodeIteration, or)
+        let message = "OR not satisfied".to_string();
+        validate_with(
+            component,
+            shape,
+            value_nodes,
+            ValueNodeIteration,
+            or,
+            &message,
+            maybe_path,
+        )
     }
 }
 
-impl<S: Query + Debug + 'static> NativeValidator<S> for Or<S> {
+impl<S: NeighsRDF + Debug + 'static> NativeValidator<S> for Or {
     fn validate_native(
         &self,
-        component: &CompiledComponent<S>,
-        shape: &CompiledShape<S>,
+        component: &CompiledComponent,
+        shape: &CompiledShape,
         store: &S,
         value_nodes: &ValueNodes<S>,
+        source_shape: Option<&CompiledShape>,
+        maybe_path: Option<SHACLPath>,
     ) -> Result<Vec<ValidationResult>, ConstraintError> {
-        self.validate(component, shape, store, NativeEngine, value_nodes)
+        self.validate(
+            component,
+            shape,
+            store,
+            NativeEngine,
+            value_nodes,
+            source_shape,
+            maybe_path,
+        )
     }
 }
 
-impl<S: Sparql + Debug + 'static> SparqlValidator<S> for Or<S> {
+impl<S: QueryRDF + Debug + 'static> SparqlValidator<S> for Or {
     fn validate_sparql(
         &self,
-        component: &CompiledComponent<S>,
-        shape: &CompiledShape<S>,
+        component: &CompiledComponent,
+        shape: &CompiledShape,
         store: &S,
         value_nodes: &ValueNodes<S>,
+        source_shape: Option<&CompiledShape>,
+        maybe_path: Option<SHACLPath>,
     ) -> Result<Vec<ValidationResult>, ConstraintError> {
-        self.validate(component, shape, store, SparqlEngine, value_nodes)
+        self.validate(
+            component,
+            shape,
+            store,
+            SparqlEngine,
+            value_nodes,
+            source_shape,
+            maybe_path,
+        )
     }
 }
