@@ -3,32 +3,37 @@ use crate::constraints::NativeValidator;
 use crate::constraints::SparqlValidator;
 use crate::validation_report::result::ValidationResult;
 use crate::value_nodes::ValueNodes;
-use shacl_ast::compiled::component::CompiledComponent;
-use shacl_ast::compiled::component::Disjoint;
-use shacl_ast::compiled::shape::CompiledShape;
-use srdf::Query;
-use srdf::Sparql;
+use shacl_ir::compiled::component::CompiledComponent;
+use shacl_ir::compiled::component::Disjoint;
+use shacl_ir::compiled::shape::CompiledShape;
+use srdf::NeighsRDF;
+use srdf::QueryRDF;
+use srdf::SHACLPath;
 use std::fmt::Debug;
 
-impl<S: Query + Debug + 'static> NativeValidator<S> for Disjoint<S> {
+impl<S: NeighsRDF + Debug + 'static> NativeValidator<S> for Disjoint {
     fn validate_native(
         &self,
-        _component: &CompiledComponent<S>,
-        _shape: &CompiledShape<S>,
+        _component: &CompiledComponent,
+        _shape: &CompiledShape,
         _store: &S,
         _value_nodes: &ValueNodes<S>,
+        _source_shape: Option<&CompiledShape>,
+        _maybe_path: Option<SHACLPath>,
     ) -> Result<Vec<ValidationResult>, ConstraintError> {
         Err(ConstraintError::NotImplemented("Disjoint".to_string()))
     }
 }
 
-impl<S: Sparql + Debug + 'static> SparqlValidator<S> for Disjoint<S> {
+impl<S: QueryRDF + Debug + 'static> SparqlValidator<S> for Disjoint {
     fn validate_sparql(
         &self,
-        _component: &CompiledComponent<S>,
-        _shape: &CompiledShape<S>,
+        _component: &CompiledComponent,
+        _shape: &CompiledShape,
         _store: &S,
         _value_nodes: &ValueNodes<S>,
+        _source_shape: Option<&CompiledShape>,
+        _maybe_path: Option<SHACLPath>,
     ) -> Result<Vec<ValidationResult>, ConstraintError> {
         Err(ConstraintError::NotImplemented("Disjoint".to_string()))
     }
