@@ -1,11 +1,12 @@
-use shacl_ast::compiled::component::CompiledComponent;
-use shacl_ast::compiled::component::LanguageIn;
-use shacl_ast::compiled::shape::CompiledShape;
+use shacl_ir::compiled::component::CompiledComponent;
+use shacl_ir::compiled::component::LanguageIn;
+use shacl_ir::compiled::shape::CompiledShape;
 use srdf::lang::Lang;
 use srdf::Literal;
-use srdf::Query;
+use srdf::NeighsRDF;
+use srdf::QueryRDF;
 use srdf::Rdf;
-use srdf::Sparql;
+use srdf::SHACLPath;
 use std::fmt::Debug;
 
 use crate::constraints::constraint_error::ConstraintError;
@@ -23,15 +24,16 @@ use crate::value_nodes::ValueNodes;
 impl<S: Rdf + Debug> Validator<S> for LanguageIn {
     fn validate(
         &self,
-        component: &CompiledComponent<S>,
-        shape: &CompiledShape<S>,
+        component: &CompiledComponent,
+        shape: &CompiledShape,
         _: &S,
         _: impl Engine<S>,
         value_nodes: &ValueNodes<S>,
+        _source_shape: Option<&CompiledShape>,
+        maybe_path: Option<SHACLPath>,
     ) -> Result<Vec<ValidationResult>, ConstraintError> {
         let language_in = |value_node: &S::Term| {
-            if let Ok(literal) = value_node.clone().try_into() {
-                let literal: S::Literal = literal;
+            if let Ok(literal) = S::term_as_literal(value_node) {
                 return match literal.lang() {
                     Some(lang) => !self.langs().contains(&Lang::new_unchecked(lang)),
                     None => true,
@@ -40,36 +42,62 @@ impl<S: Rdf + Debug> Validator<S> for LanguageIn {
             true
         };
 
+        let message = format!(
+            "LanguageIn constraint not satisfied. Expected one of: {:?}",
+            self.langs()
+        );
         validate_with(
             component,
             shape,
             value_nodes,
             ValueNodeIteration,
             language_in,
+            &message,
+            maybe_path,
         )
     }
 }
 
-impl<S: Query + Debug + 'static> NativeValidator<S> for LanguageIn {
+impl<S: NeighsRDF + Debug + 'static> NativeValidator<S> for LanguageIn {
     fn validate_native<'a>(
         &self,
-        component: &CompiledComponent<S>,
-        shape: &CompiledShape<S>,
+        component: &CompiledComponent,
+        shape: &CompiledShape,
         store: &S,
         value_nodes: &ValueNodes<S>,
+        source_shape: Option<&CompiledShape>,
+        maybe_path: Option<SHACLPath>,
     ) -> Result<Vec<ValidationResult>, ConstraintError> {
-        self.validate(component, shape, store, NativeEngine, value_nodes)
+        self.validate(
+            component,
+            shape,
+            store,
+            NativeEngine,
+            value_nodes,
+            source_shape,
+            maybe_path,
+        )
     }
 }
 
-impl<S: Sparql + Debug + 'static> SparqlValidator<S> for LanguageIn {
+impl<S: QueryRDF + Debug + 'static> SparqlValidator<S> for LanguageIn {
     fn validate_sparql(
         &self,
-        component: &CompiledComponent<S>,
-        shape: &CompiledShape<S>,
+        component: &CompiledComponent,
+        shape: &CompiledShape,
         store: &S,
         value_nodes: &ValueNodes<S>,
+        source_shape: Option<&CompiledShape>,
+        maybe_path: Option<SHACLPath>,
     ) -> Result<Vec<ValidationResult>, ConstraintError> {
-        self.validate(component, shape, store, SparqlEngine, value_nodes)
+        self.validate(
+            component,
+            shape,
+            store,
+            SparqlEngine,
+            value_nodes,
+            source_shape,
+            maybe_path,
+        )
     }
 }
