@@ -9,22 +9,25 @@ use crate::validation_report::result::ValidationResult;
 use crate::value_nodes::ValueNodeIteration;
 use crate::value_nodes::ValueNodes;
 use indoc::formatdoc;
-use shacl_ast::compiled::component::CompiledComponent;
-use shacl_ast::compiled::component::Nodekind;
-use shacl_ast::compiled::shape::CompiledShape;
 use shacl_ast::node_kind::NodeKind;
-use srdf::Query;
-use srdf::Sparql;
+use shacl_ir::compiled::component::CompiledComponent;
+use shacl_ir::compiled::component::Nodekind;
+use shacl_ir::compiled::shape::CompiledShape;
+use srdf::NeighsRDF;
+use srdf::QueryRDF;
+use srdf::SHACLPath;
 use srdf::Term;
 use std::fmt::Debug;
 
-impl<S: Query + Debug + 'static> NativeValidator<S> for Nodekind {
+impl<S: NeighsRDF + Debug + 'static> NativeValidator<S> for Nodekind {
     fn validate_native(
         &self,
-        component: &CompiledComponent<S>,
-        shape: &CompiledShape<S>,
+        component: &CompiledComponent,
+        shape: &CompiledShape,
         _: &S,
         value_nodes: &ValueNodes<S>,
+        _source_shape: Option<&CompiledShape>,
+        maybe_path: Option<SHACLPath>,
     ) -> Result<Vec<ValidationResult>, ConstraintError> {
         let node_kind = |value_node: &S::Term| {
             match (
@@ -49,17 +52,31 @@ impl<S: Query + Debug + 'static> NativeValidator<S> for Nodekind {
             .not()
         };
 
-        validate_with(component, shape, value_nodes, ValueNodeIteration, node_kind)
+        let message = format!(
+            "Nodekind constraint not satisfied. Expected node kind: {}",
+            self.node_kind()
+        );
+        validate_with(
+            component,
+            shape,
+            value_nodes,
+            ValueNodeIteration,
+            node_kind,
+            &message,
+            maybe_path,
+        )
     }
 }
 
-impl<S: Sparql + Debug + 'static> SparqlValidator<S> for Nodekind {
+impl<S: QueryRDF + Debug + 'static> SparqlValidator<S> for Nodekind {
     fn validate_sparql(
         &self,
-        component: &CompiledComponent<S>,
-        shape: &CompiledShape<S>,
+        component: &CompiledComponent,
+        shape: &CompiledShape,
         store: &S,
         value_nodes: &ValueNodes<S>,
+        _source_shape: Option<&CompiledShape>,
+        maybe_path: Option<SHACLPath>,
     ) -> Result<Vec<ValidationResult>, ConstraintError> {
         let node_kind = self.node_kind().clone();
 
@@ -85,6 +102,18 @@ impl<S: Sparql + Debug + 'static> SparqlValidator<S> for Nodekind {
             }
         };
 
-        validate_ask_with(component, shape, store, value_nodes, query)
+        let message = format!(
+            "Nodekind constraint not satisfied. Expected node kind: {}",
+            self.node_kind()
+        );
+        validate_ask_with(
+            component,
+            shape,
+            store,
+            value_nodes,
+            query,
+            &message,
+            maybe_path,
+        )
     }
 }
