@@ -1,7 +1,9 @@
-use shacl_ast::compiled::component::CompiledComponent;
-use shacl_ast::compiled::property_shape::CompiledPropertyShape;
-use shacl_ast::compiled::shape::CompiledShape;
-use shacl_ast::compiled::target::CompiledTarget;
+use iri_s::IriS;
+use shacl_ir::compiled::component::CompiledComponent;
+use shacl_ir::compiled::property_shape::CompiledPropertyShape;
+use shacl_ir::compiled::shape::CompiledShape;
+use shacl_ir::compiled::target::CompiledTarget;
+use srdf::RDFNode;
 use srdf::Rdf;
 use srdf::SHACLPath;
 
@@ -17,15 +19,17 @@ pub trait Engine<S: Rdf> {
     fn evaluate(
         &self,
         store: &S,
-        shape: &CompiledShape<S>,
-        component: &CompiledComponent<S>,
+        shape: &CompiledShape,
+        component: &CompiledComponent,
         value_nodes: &ValueNodes<S>,
+        source_shape: Option<&CompiledShape>,
+        maybe_path: Option<SHACLPath>,
     ) -> Result<Vec<ValidationResult>, ValidateError>;
 
     fn focus_nodes(
         &self,
         store: &S,
-        targets: &[CompiledTarget<S>],
+        targets: &[CompiledTarget],
     ) -> Result<FocusNodes<S>, ValidateError> {
         // TODO: here it would be nice to return an error...
         let targets = targets
@@ -35,7 +39,12 @@ pub trait Engine<S: Rdf> {
                 CompiledTarget::Class(class) => self.target_class(store, class),
                 CompiledTarget::SubjectsOf(predicate) => self.target_subject_of(store, predicate),
                 CompiledTarget::ObjectsOf(predicate) => self.target_object_of(store, predicate),
-                CompiledTarget::ImplicitClass(class) => self.implicit_target_class(store, class),
+                CompiledTarget::ImplicitClass(node) => self.implicit_target_class(store, node),
+                CompiledTarget::WrongTargetNode(_) => todo!(),
+                CompiledTarget::WrongTargetClass(_) => todo!(),
+                CompiledTarget::WrongSubjectsOf(_) => todo!(),
+                CompiledTarget::WrongObjectsOf(_) => todo!(),
+                CompiledTarget::WrongImplicitClass(_) => todo!(),
             })
             .flatten();
 
@@ -44,32 +53,29 @@ pub trait Engine<S: Rdf> {
 
     /// If s is a shape in a shapes graph SG and s has value t for sh:targetNode
     /// in SG then { t } is a target from any data graph for s in SG.
-    fn target_node(&self, store: &S, node: &S::Term) -> Result<FocusNodes<S>, ValidateError>;
+    fn target_node(&self, store: &S, node: &RDFNode) -> Result<FocusNodes<S>, ValidateError>;
 
-    fn target_class(&self, store: &S, class: &S::Term) -> Result<FocusNodes<S>, ValidateError>;
+    fn target_class(&self, store: &S, class: &RDFNode) -> Result<FocusNodes<S>, ValidateError>;
 
     fn target_subject_of(
         &self,
         store: &S,
-        predicate: &S::IRI,
+        predicate: &IriS,
     ) -> Result<FocusNodes<S>, ValidateError>;
 
-    fn target_object_of(
-        &self,
-        store: &S,
-        predicate: &S::IRI,
-    ) -> Result<FocusNodes<S>, ValidateError>;
+    fn target_object_of(&self, store: &S, predicate: &IriS)
+        -> Result<FocusNodes<S>, ValidateError>;
 
     fn implicit_target_class(
         &self,
         store: &S,
-        shape: &S::Term,
+        shape: &RDFNode,
     ) -> Result<FocusNodes<S>, ValidateError>;
 
     fn path(
         &self,
         store: &S,
-        shape: &CompiledPropertyShape<S>,
+        shape: &CompiledPropertyShape,
         focus_node: &S::Term,
     ) -> Result<FocusNodes<S>, ValidateError> {
         match shape.path() {
@@ -88,7 +94,7 @@ pub trait Engine<S: Rdf> {
     fn predicate(
         &self,
         store: &S,
-        shape: &CompiledPropertyShape<S>,
+        shape: &CompiledPropertyShape,
         predicate: &S::IRI,
         focus_node: &S::Term,
     ) -> Result<FocusNodes<S>, ValidateError>;
@@ -96,7 +102,7 @@ pub trait Engine<S: Rdf> {
     fn alternative(
         &self,
         store: &S,
-        shape: &CompiledPropertyShape<S>,
+        shape: &CompiledPropertyShape,
         paths: &[SHACLPath],
         focus_node: &S::Term,
     ) -> Result<FocusNodes<S>, ValidateError>;
@@ -104,7 +110,7 @@ pub trait Engine<S: Rdf> {
     fn sequence(
         &self,
         store: &S,
-        shape: &CompiledPropertyShape<S>,
+        shape: &CompiledPropertyShape,
         paths: &[SHACLPath],
         focus_node: &S::Term,
     ) -> Result<FocusNodes<S>, ValidateError>;
@@ -112,7 +118,7 @@ pub trait Engine<S: Rdf> {
     fn inverse(
         &self,
         store: &S,
-        shape: &CompiledPropertyShape<S>,
+        shape: &CompiledPropertyShape,
         path: &SHACLPath,
         focus_node: &S::Term,
     ) -> Result<FocusNodes<S>, ValidateError>;
@@ -120,7 +126,7 @@ pub trait Engine<S: Rdf> {
     fn zero_or_more(
         &self,
         store: &S,
-        shape: &CompiledPropertyShape<S>,
+        shape: &CompiledPropertyShape,
         path: &SHACLPath,
         focus_node: &S::Term,
     ) -> Result<FocusNodes<S>, ValidateError>;
@@ -128,7 +134,7 @@ pub trait Engine<S: Rdf> {
     fn one_or_more(
         &self,
         store: &S,
-        shape: &CompiledPropertyShape<S>,
+        shape: &CompiledPropertyShape,
         path: &SHACLPath,
         focus_node: &S::Term,
     ) -> Result<FocusNodes<S>, ValidateError>;
@@ -136,7 +142,7 @@ pub trait Engine<S: Rdf> {
     fn zero_or_one(
         &self,
         store: &S,
-        shape: &CompiledPropertyShape<S>,
+        shape: &CompiledPropertyShape,
         path: &SHACLPath,
         focus_node: &S::Term,
     ) -> Result<FocusNodes<S>, ValidateError>;
