@@ -1,16 +1,18 @@
-use shacl_ast::compiled::component::CompiledComponent;
-use shacl_ast::compiled::property_shape::CompiledPropertyShape;
-use shacl_ast::compiled::shape::CompiledShape;
-use srdf::matcher::Any;
-use srdf::Query;
+use iri_s::IriS;
+use shacl_ir::compiled::component::CompiledComponent;
+use shacl_ir::compiled::property_shape::CompiledPropertyShape;
+use shacl_ir::compiled::shape::CompiledShape;
+use srdf::rdf_type;
+use srdf::rdfs_subclass_of;
+use srdf::NeighsRDF;
+use srdf::RDFNode;
 use srdf::SHACLPath;
 use srdf::Term;
 use srdf::Triple;
-use srdf::RDFS_SUBCLASS_OF;
-use srdf::RDF_TYPE;
 
 use super::Engine;
 use crate::constraints::NativeDeref;
+use crate::constraints::ShaclComponent;
 use crate::focus_nodes::FocusNodes;
 use crate::helpers::srdf::get_objects_for;
 use crate::helpers::srdf::get_subjects_for;
@@ -21,21 +23,32 @@ use std::fmt::Debug;
 
 pub struct NativeEngine;
 
-impl<S: Query + Debug + 'static> Engine<S> for NativeEngine {
+impl<S: NeighsRDF + Debug + 'static> Engine<S> for NativeEngine {
     fn evaluate(
         &self,
         store: &S,
-        shape: &CompiledShape<S>,
-        component: &CompiledComponent<S>,
+        shape: &CompiledShape,
+        component: &CompiledComponent,
         value_nodes: &ValueNodes<S>,
+        source_shape: Option<&CompiledShape>,
+        maybe_path: Option<SHACLPath>,
     ) -> Result<Vec<ValidationResult>, ValidateError> {
-        let validator = component.deref();
-        Ok(validator.validate_native(component, shape, store, value_nodes)?)
+        tracing::debug!("NativeEngine, evaluate with shape {}", shape.id());
+        let shacl_component = ShaclComponent::new(component);
+        let validator = shacl_component.deref();
+        Ok(validator.validate_native(
+            component,
+            shape,
+            store,
+            value_nodes,
+            source_shape,
+            maybe_path,
+        )?)
     }
 
-    /// If s is a shape in a shapes graph SG and s has value t for sh:targetNode
-    /// in SG then { t } is a target from any data graph for s in SG.
-    fn target_node(&self, _: &S, node: &S::Term) -> Result<FocusNodes<S>, ValidateError> {
+    /// https://www.w3.org/TR/shacl/#targetNode
+    fn target_node(&self, _: &S, node: &RDFNode) -> Result<FocusNodes<S>, ValidateError> {
+        let node: S::Term = node.clone().into();
         if node.is_blank_node() {
             Err(ValidateError::TargetNodeBlankNode)
         } else {
@@ -43,19 +56,15 @@ impl<S: Query + Debug + 'static> Engine<S> for NativeEngine {
         }
     }
 
-    fn target_class(&self, store: &S, class: &S::Term) -> Result<FocusNodes<S>, ValidateError> {
-        if !class.is_iri() {
-            return Err(ValidateError::TargetClassNotIri);
-        }
-
+    fn target_class(&self, store: &S, class: &RDFNode) -> Result<FocusNodes<S>, ValidateError> {
         // TODO: this should not be necessary, check in others triples_matching calls
-        let rdf_type: S::IRI = RDF_TYPE.clone().into();
-
+        let cls: S::Term = class.clone().into();
         let focus_nodes = store
-            .triples_matching(Any, rdf_type, class.clone())
-            .map_err(|_| ValidateError::SRDF)?
-            .map(Triple::into_subject)
-            .map(Into::into);
+            .shacl_instances_of(cls)
+            .map_err(|e| ValidateError::TargetClassError {
+                msg: format!("Failed to get instances of class {class}: {e}"),
+            })?
+            .map(|subj| S::subject_as_term(&subj));
 
         Ok(FocusNodes::new(focus_nodes))
     }
@@ -63,10 +72,11 @@ impl<S: Query + Debug + 'static> Engine<S> for NativeEngine {
     fn target_subject_of(
         &self,
         store: &S,
-        predicate: &S::IRI,
+        predicate: &IriS,
     ) -> Result<FocusNodes<S>, ValidateError> {
+        let pred: S::IRI = predicate.clone().into();
         let subjects = store
-            .triples_with_predicate(predicate.clone())
+            .triples_with_predicate(pred)
             .map_err(|_| ValidateError::SRDF)?
             .map(Triple::into_subject)
             .map(Into::into);
@@ -77,10 +87,11 @@ impl<S: Query + Debug + 'static> Engine<S> for NativeEngine {
     fn target_object_of(
         &self,
         store: &S,
-        predicate: &S::IRI,
+        predicate: &IriS,
     ) -> Result<FocusNodes<S>, ValidateError> {
+        let pred: S::IRI = predicate.clone().into();
         let objects = store
-            .triples_with_predicate(predicate.clone())
+            .triples_with_predicate(pred)
             .map_err(|_| ValidateError::SRDF)?
             .map(Triple::into_object);
         Ok(FocusNodes::new(objects))
@@ -89,17 +100,20 @@ impl<S: Query + Debug + 'static> Engine<S> for NativeEngine {
     fn implicit_target_class(
         &self,
         store: &S,
-        subject: &S::Term,
+        subject: &RDFNode,
     ) -> Result<FocusNodes<S>, ValidateError> {
-        let targets = get_subjects_for(store, &RDF_TYPE.clone().into(), subject)?;
+        // TODO: Replace by shacl_instances_of
+        let subject: S::Term = subject.clone().into();
+        let targets = get_subjects_for(store, &rdf_type().clone().into(), &subject)?;
 
-        let subclass_targets = get_subjects_for(store, &RDFS_SUBCLASS_OF.clone().into(), subject)?
-            .into_iter()
-            .flat_map(move |subclass| {
-                get_subjects_for(store, &RDF_TYPE.clone().into(), &subclass)
-                    .into_iter()
-                    .flatten()
-            });
+        let subclass_targets =
+            get_subjects_for(store, &rdfs_subclass_of().clone().into(), &subject)?
+                .into_iter()
+                .flat_map(move |subclass| {
+                    get_subjects_for(store, &rdf_type().clone().into(), &subclass)
+                        .into_iter()
+                        .flatten()
+                });
 
         Ok(FocusNodes::new(targets.into_iter().chain(subclass_targets)))
     }
@@ -107,7 +121,7 @@ impl<S: Query + Debug + 'static> Engine<S> for NativeEngine {
     fn predicate(
         &self,
         store: &S,
-        _: &CompiledPropertyShape<S>,
+        _: &CompiledPropertyShape,
         predicate: &S::IRI,
         focus_node: &S::Term,
     ) -> Result<FocusNodes<S>, ValidateError> {
@@ -119,7 +133,7 @@ impl<S: Query + Debug + 'static> Engine<S> for NativeEngine {
     fn alternative(
         &self,
         _store: &S,
-        _shape: &CompiledPropertyShape<S>,
+        _shape: &CompiledPropertyShape,
         _paths: &[SHACLPath],
         _focus_node: &S::Term,
     ) -> Result<FocusNodes<S>, ValidateError> {
@@ -131,7 +145,7 @@ impl<S: Query + Debug + 'static> Engine<S> for NativeEngine {
     fn sequence(
         &self,
         _store: &S,
-        _shape: &CompiledPropertyShape<S>,
+        _shape: &CompiledPropertyShape,
         _paths: &[SHACLPath],
         _focus_node: &S::Term,
     ) -> Result<FocusNodes<S>, ValidateError> {
@@ -143,7 +157,7 @@ impl<S: Query + Debug + 'static> Engine<S> for NativeEngine {
     fn inverse(
         &self,
         _store: &S,
-        _shape: &CompiledPropertyShape<S>,
+        _shape: &CompiledPropertyShape,
         _path: &SHACLPath,
         _focus_node: &S::Term,
     ) -> Result<FocusNodes<S>, ValidateError> {
@@ -155,7 +169,7 @@ impl<S: Query + Debug + 'static> Engine<S> for NativeEngine {
     fn zero_or_more(
         &self,
         _store: &S,
-        _shape: &CompiledPropertyShape<S>,
+        _shape: &CompiledPropertyShape,
         _path: &SHACLPath,
         _focus_node: &S::Term,
     ) -> Result<FocusNodes<S>, ValidateError> {
@@ -167,7 +181,7 @@ impl<S: Query + Debug + 'static> Engine<S> for NativeEngine {
     fn one_or_more(
         &self,
         _store: &S,
-        _shape: &CompiledPropertyShape<S>,
+        _shape: &CompiledPropertyShape,
         _path: &SHACLPath,
         _focus_node: &S::Term,
     ) -> Result<FocusNodes<S>, ValidateError> {
@@ -179,7 +193,7 @@ impl<S: Query + Debug + 'static> Engine<S> for NativeEngine {
     fn zero_or_one(
         &self,
         _store: &S,
-        _shape: &CompiledPropertyShape<S>,
+        _shape: &CompiledPropertyShape,
         _path: &SHACLPath,
         _focus_node: &S::Term,
     ) -> Result<FocusNodes<S>, ValidateError> {
