@@ -1,37 +1,50 @@
-use indoc::formatdoc;
-use shacl_ast::compiled::component::CompiledComponent;
-use shacl_ast::compiled::property_shape::CompiledPropertyShape;
-use shacl_ast::compiled::shape::CompiledShape;
-use srdf::SHACLPath;
-use srdf::Sparql;
-use srdf::Term;
-
 use super::Engine;
+use crate::constraints::ShaclComponent;
 use crate::constraints::SparqlDeref;
 use crate::focus_nodes::FocusNodes;
 use crate::helpers::sparql::select;
 use crate::validate_error::ValidateError;
 use crate::validation_report::result::ValidationResult;
 use crate::value_nodes::ValueNodes;
+use indoc::formatdoc;
+use iri_s::IriS;
+use shacl_ir::compiled::component::CompiledComponent;
+use shacl_ir::compiled::property_shape::CompiledPropertyShape;
+use shacl_ir::compiled::shape::CompiledShape;
+use srdf::QueryRDF;
+use srdf::RDFNode;
+use srdf::SHACLPath;
+use srdf::Term;
 use std::fmt::Debug;
 
 pub struct SparqlEngine;
 
-impl<S: Sparql + Debug + 'static> Engine<S> for SparqlEngine {
+impl<S: QueryRDF + Debug + 'static> Engine<S> for SparqlEngine {
     fn evaluate(
         &self,
         store: &S,
-        shape: &CompiledShape<S>,
-        component: &CompiledComponent<S>,
+        shape: &CompiledShape,
+        component: &CompiledComponent,
         value_nodes: &ValueNodes<S>,
+        source_shape: Option<&CompiledShape>,
+        maybe_path: Option<SHACLPath>,
     ) -> Result<Vec<ValidationResult>, ValidateError> {
-        let validator = component.deref();
-        Ok(validator.validate_sparql(component, shape, store, value_nodes)?)
+        let shacl_component = ShaclComponent::new(component);
+        let validator = shacl_component.deref();
+        Ok(validator.validate_sparql(
+            component,
+            shape,
+            store,
+            value_nodes,
+            source_shape,
+            maybe_path,
+        )?)
     }
 
     /// If s is a shape in a shapes graph SG and s has value t for sh:targetNode
     /// in SG then { t } is a target from any data graph for s in SG.
-    fn target_node(&self, store: &S, node: &S::Term) -> Result<FocusNodes<S>, ValidateError> {
+    fn target_node(&self, store: &S, node: &RDFNode) -> Result<FocusNodes<S>, ValidateError> {
+        let node: S::Term = node.clone().into();
         if node.is_blank_node() {
             return Err(ValidateError::TargetNodeBlankNode);
         }
@@ -50,7 +63,8 @@ impl<S: Sparql + Debug + 'static> Engine<S> for SparqlEngine {
         })
     }
 
-    fn target_class(&self, store: &S, class: &S::Term) -> Result<FocusNodes<S>, ValidateError> {
+    fn target_class(&self, store: &S, class: &RDFNode) -> Result<FocusNodes<S>, ValidateError> {
+        let class: S::Term = class.clone().into();
         if !class.is_iri() {
             return Err(ValidateError::TargetClassNotIri);
         }
@@ -75,7 +89,7 @@ impl<S: Sparql + Debug + 'static> Engine<S> for SparqlEngine {
     fn target_subject_of(
         &self,
         store: &S,
-        predicate: &S::IRI,
+        predicate: &IriS,
     ) -> Result<FocusNodes<S>, ValidateError> {
         let query = formatdoc! {"
             SELECT DISTINCT ?this
@@ -94,7 +108,7 @@ impl<S: Sparql + Debug + 'static> Engine<S> for SparqlEngine {
     fn target_object_of(
         &self,
         store: &S,
-        predicate: &S::IRI,
+        predicate: &IriS,
     ) -> Result<FocusNodes<S>, ValidateError> {
         let query = formatdoc! {"
             SELECT DISTINCT ?this
@@ -113,7 +127,7 @@ impl<S: Sparql + Debug + 'static> Engine<S> for SparqlEngine {
     fn implicit_target_class(
         &self,
         _store: &S,
-        _shape: &S::Term,
+        _shape: &RDFNode,
     ) -> Result<FocusNodes<S>, ValidateError> {
         Err(ValidateError::NotImplemented {
             msg: "implicit_target_class".to_string(),
@@ -123,7 +137,7 @@ impl<S: Sparql + Debug + 'static> Engine<S> for SparqlEngine {
     fn predicate(
         &self,
         _store: &S,
-        _shape: &CompiledPropertyShape<S>,
+        _shape: &CompiledPropertyShape,
         _predicate: &S::IRI,
         _focus_node: &S::Term,
     ) -> Result<FocusNodes<S>, ValidateError> {
@@ -135,7 +149,7 @@ impl<S: Sparql + Debug + 'static> Engine<S> for SparqlEngine {
     fn alternative(
         &self,
         _store: &S,
-        _shape: &CompiledPropertyShape<S>,
+        _shape: &CompiledPropertyShape,
         _paths: &[SHACLPath],
         _focus_node: &S::Term,
     ) -> Result<FocusNodes<S>, ValidateError> {
@@ -147,7 +161,7 @@ impl<S: Sparql + Debug + 'static> Engine<S> for SparqlEngine {
     fn sequence(
         &self,
         _store: &S,
-        _shape: &CompiledPropertyShape<S>,
+        _shape: &CompiledPropertyShape,
         _paths: &[SHACLPath],
         _focus_node: &S::Term,
     ) -> Result<FocusNodes<S>, ValidateError> {
@@ -159,7 +173,7 @@ impl<S: Sparql + Debug + 'static> Engine<S> for SparqlEngine {
     fn inverse(
         &self,
         _store: &S,
-        _shape: &CompiledPropertyShape<S>,
+        _shape: &CompiledPropertyShape,
         _path: &SHACLPath,
         _focus_node: &S::Term,
     ) -> Result<FocusNodes<S>, ValidateError> {
@@ -171,7 +185,7 @@ impl<S: Sparql + Debug + 'static> Engine<S> for SparqlEngine {
     fn zero_or_more(
         &self,
         _store: &S,
-        _shape: &CompiledPropertyShape<S>,
+        _shape: &CompiledPropertyShape,
         _path: &SHACLPath,
         _focus_node: &S::Term,
     ) -> Result<FocusNodes<S>, ValidateError> {
@@ -183,7 +197,7 @@ impl<S: Sparql + Debug + 'static> Engine<S> for SparqlEngine {
     fn one_or_more(
         &self,
         _store: &S,
-        _shape: &CompiledPropertyShape<S>,
+        _shape: &CompiledPropertyShape,
         _path: &SHACLPath,
         _focus_node: &S::Term,
     ) -> Result<FocusNodes<S>, ValidateError> {
@@ -195,7 +209,7 @@ impl<S: Sparql + Debug + 'static> Engine<S> for SparqlEngine {
     fn zero_or_one(
         &self,
         _store: &S,
-        _shape: &CompiledPropertyShape<S>,
+        _shape: &CompiledPropertyShape,
         _path: &SHACLPath,
         _focus_node: &S::Term,
     ) -> Result<FocusNodes<S>, ValidateError> {
