@@ -1,10 +1,10 @@
 use std::collections::HashSet;
 
-use srdf::{matcher::Any, Query, RDFNode, Triple};
+use srdf::{matcher::Any, NeighsRDF, Object, RDFNode, SHACLPath, Triple};
 
 use super::helper_error::SRDFError;
 
-pub(crate) fn get_object_for<S: Query>(
+pub(crate) fn get_object_for<S: NeighsRDF>(
     store: &S,
     subject: &S::Term,
     predicate: &S::IRI,
@@ -13,17 +13,20 @@ pub(crate) fn get_object_for<S: Query>(
         .into_iter()
         .next()
     {
-        Some(term) => Ok(Some(term.into())),
+        Some(term) => {
+            let obj = S::term_as_object(&term)?;
+            Ok(Some(obj))
+        }
         None => Ok(None),
     }
 }
 
-pub(crate) fn get_objects_for<S: Query>(
+pub(crate) fn get_objects_for<S: NeighsRDF>(
     store: &S,
     subject: &S::Term,
     predicate: &S::IRI,
 ) -> Result<HashSet<S::Term>, SRDFError> {
-    let subject: S::Subject = match subject.clone().try_into() {
+    let subject: S::Subject = match S::term_as_subject(subject) {
         Ok(subject) => subject,
         Err(_) => {
             return Err(SRDFError::SRDFTermAsSubject {
@@ -43,7 +46,7 @@ pub(crate) fn get_objects_for<S: Query>(
     Ok(triples)
 }
 
-pub(crate) fn get_subjects_for<S: Query>(
+pub(crate) fn get_subjects_for<S: NeighsRDF>(
     store: &S,
     predicate: &S::IRI,
     object: &S::Term,
@@ -58,3 +61,26 @@ pub(crate) fn get_subjects_for<S: Query>(
         .collect();
     Ok(values)
 }
+
+pub(crate) fn get_path_for<S: NeighsRDF>(
+    store: &S,
+    subject: &S::Term,
+    predicate: &S::IRI,
+) -> Result<Option<SHACLPath>, SRDFError> {
+    match get_objects_for(store, subject, predicate)?
+        .into_iter()
+        .next()
+    {
+        Some(term) => {
+            let obj: Object = S::term_as_object(&term)?;
+            match obj {
+                Object::Iri(iri_s) => Ok(Some(SHACLPath::iri(iri_s))),
+                Object::BlankNode(_) => todo!(),
+                Object::Literal(literal) => Err(SRDFError::SHACLUnexpectedLiteral {
+                    lit: literal.to_string(),
+                }),
+            }
+        }
+        None => Ok(None),
+    }
+}
