@@ -3,9 +3,9 @@ use crate::focus_nodes::FocusNodes;
 use crate::validate_error::ValidateError;
 use crate::validation_report::result::ValidationResult;
 use crate::value_nodes::ValueNodes;
-use shacl_ast::compiled::node_shape::CompiledNodeShape;
-use shacl_ast::compiled::property_shape::CompiledPropertyShape;
-use shacl_ast::compiled::shape::CompiledShape;
+use shacl_ir::compiled::node_shape::CompiledNodeShape;
+use shacl_ir::compiled::property_shape::CompiledPropertyShape;
+use shacl_ir::compiled::shape::CompiledShape;
 use srdf::Rdf;
 use std::fmt::Debug;
 
@@ -16,16 +16,25 @@ pub trait Validate<S: Rdf> {
         store: &S,
         runner: &dyn Engine<S>,
         targets: Option<&FocusNodes<S>>,
+        source_shape: Option<&CompiledShape>,
     ) -> Result<Vec<ValidationResult>, ValidateError>;
 }
 
-impl<S: Rdf + Debug> Validate<S> for CompiledShape<S> {
+impl<S: Rdf + Debug> Validate<S> for CompiledShape {
     fn validate(
         &self,
         store: &S,
         runner: &dyn Engine<S>,
         targets: Option<&FocusNodes<S>>,
+        source_shape: Option<&CompiledShape>,
     ) -> Result<Vec<ValidationResult>, ValidateError> {
+        tracing::debug!(
+            "Shape.validate with shape {} and source shape: {}",
+            self.id(),
+            source_shape
+                .map(|s| format!("{}", s.id()))
+                .unwrap_or_else(|| "None".to_string())
+        );
         // 0. skipping if it is deactivated
         if *self.is_deactivated() {
             return Ok(Vec::default());
@@ -43,20 +52,26 @@ impl<S: Rdf + Debug> Validate<S> for CompiledShape<S> {
         let value_nodes = self.value_nodes(store, &focus_nodes, runner);
 
         // 3.
-        let component_validation_results = self
-            .components()
-            .iter()
-            .flat_map(move |component| runner.evaluate(store, self, component, &value_nodes));
+        let component_validation_results = self.components().iter().flat_map(move |component| {
+            runner.evaluate(
+                store,
+                self,
+                component,
+                &value_nodes,
+                source_shape,
+                self.path(),
+            )
+        });
 
         // 4. After validating the constraints that are defined in the current
         //    Shape, it is important to also perform the validation over those
         //    nested PropertyShapes. The thing is that the validation needs to
         //    occur over the focus_nodes that have been computed for the current
         //    shape
-        let property_shapes_validation_results = self
-            .property_shapes()
-            .iter()
-            .flat_map(|shape| shape.validate(store, runner, Some(&focus_nodes)));
+        let property_shapes_validation_results =
+            self.property_shapes().iter().flat_map(|prop_shape| {
+                prop_shape.validate(store, runner, Some(&focus_nodes), Some(self))
+            });
 
         // 5.
         let validation_results = component_validation_results
@@ -72,7 +87,7 @@ pub trait FocusNodesOps<S: Rdf> {
     fn focus_nodes(&self, store: &S, runner: &dyn Engine<S>) -> FocusNodes<S>;
 }
 
-impl<S: Rdf> FocusNodesOps<S> for CompiledShape<S> {
+impl<S: Rdf> FocusNodesOps<S> for CompiledShape {
     fn focus_nodes(&self, store: &S, runner: &dyn Engine<S>) -> FocusNodes<S> {
         runner
             .focus_nodes(store, self.targets())
@@ -89,7 +104,7 @@ pub trait ValueNodesOps<S: Rdf> {
     ) -> ValueNodes<S>;
 }
 
-impl<S: Rdf> ValueNodesOps<S> for CompiledShape<S> {
+impl<S: Rdf> ValueNodesOps<S> for CompiledShape {
     fn value_nodes(
         &self,
         store: &S,
@@ -103,7 +118,7 @@ impl<S: Rdf> ValueNodesOps<S> for CompiledShape<S> {
     }
 }
 
-impl<S: Rdf> ValueNodesOps<S> for CompiledNodeShape<S> {
+impl<S: Rdf> ValueNodesOps<S> for CompiledNodeShape {
     fn value_nodes(&self, _: &S, focus_nodes: &FocusNodes<S>, _: &dyn Engine<S>) -> ValueNodes<S> {
         let value_nodes = focus_nodes.iter().map(|focus_node| {
             (
@@ -115,7 +130,7 @@ impl<S: Rdf> ValueNodesOps<S> for CompiledNodeShape<S> {
     }
 }
 
-impl<S: Rdf> ValueNodesOps<S> for CompiledPropertyShape<S> {
+impl<S: Rdf> ValueNodesOps<S> for CompiledPropertyShape {
     fn value_nodes(
         &self,
         store: &S,
