@@ -1,7 +1,6 @@
-use shacl_ast::compiled::schema::CompiledSchema;
-use shacl_ast::ShaclParser;
+use shacl_ir::compiled::schema::SchemaIR;
+use shacl_rdf::rdf_to_shacl::ShaclParser;
 use srdf::RDFFormat;
-use srdf::Rdf;
 use srdf::ReaderMode;
 use srdf::SRDFGraph;
 use std::io::BufRead;
@@ -18,15 +17,17 @@ pub trait Store<S> {
 pub struct ShaclDataManager;
 
 impl ShaclDataManager {
-    pub fn load<S: Rdf, R: BufRead>(
+    pub fn load<R: BufRead>(
         reader: R,
         rdf_format: RDFFormat,
         base: Option<&str>,
-    ) -> Result<CompiledSchema<S>, ValidateError> {
+    ) -> Result<SchemaIR, ValidateError> {
         let rdf = SRDFGraph::from_reader(reader, &rdf_format, base, &ReaderMode::default())?;
-
         match ShaclParser::new(rdf).parse() {
-            Ok(schema) => Ok(schema.try_into()?),
+            Ok(schema) => {
+                let schema_compiled = schema.try_into()?;
+                Ok(schema_compiled)
+            }
             Err(error) => Err(ValidateError::ShaclParser(error)),
         }
     }
