@@ -1,6 +1,6 @@
 use std::collections::HashMap;
 
-use srdf::Rdf;
+use srdf::{RDFNode, Rdf};
 
 use crate::focus_nodes::FocusNodes;
 
@@ -19,6 +19,15 @@ pub trait IterationStrategy<S: Rdf> {
         &'a self,
         value_nodes: &'a ValueNodes<S>,
     ) -> Box<dyn Iterator<Item = (&'a S::Term, &'a Self::Item)> + 'a>;
+
+    fn to_value(&self, item: &Self::Item) -> Option<S::Term>;
+
+    fn to_object(&self, item: &Self::Item) -> Option<RDFNode> {
+        match self.to_value(item) {
+            None => None,
+            Some(value) => S::term_as_object(&value).ok(),
+        }
+    }
 }
 
 pub struct FocusNodeIteration;
@@ -32,6 +41,10 @@ impl<S: Rdf> IterationStrategy<S> for FocusNodeIteration {
     ) -> Box<dyn Iterator<Item = (&'a S::Term, &'a Self::Item)> + 'a> {
         Box::new(value_nodes.0.iter())
     }
+
+    fn to_value(&self, _item: &Self::Item) -> Option<S::Term> {
+        None
+    }
 }
 
 pub struct ValueNodeIteration;
@@ -49,4 +62,8 @@ impl<S: Rdf> IterationStrategy<S> for ValueNodeIteration {
                 .map(move |value_node| (focus_node, value_node))
         }))
     }
+
+    fn to_value(&self, item: &Self::Item) -> Option<<S as Rdf>::Term> {
+        Some(item.clone())
+    }
 }
