@@ -6,12 +6,11 @@ use rust_decimal::Decimal;
 use serde::ser::SerializeMap;
 use serde::{
     de::{self, MapAccess, Unexpected, Visitor},
-    Deserialize, Serialize as SerializeTrait, Serializer,
+    Deserialize, Serialize, Serializer,
 };
-use serde_derive::Serialize;
 
 use srdf::lang::Lang;
-use srdf::literal::Literal;
+use srdf::literal::SLiteral;
 use std::{fmt, result, str::FromStr};
 use thiserror::Error;
 
@@ -55,7 +54,7 @@ impl ValueSetValue {
     }
 
     pub fn string_literal(value: &str, lang: Option<Lang>) -> ValueSetValue {
-        let ov = ObjectValue::Literal(Literal::StringLiteral {
+        let ov = ObjectValue::Literal(SLiteral::StringLiteral {
             lexical_form: value.to_string(),
             lang,
         });
@@ -208,7 +207,7 @@ impl ValueSetValueType {
 //const DOUBLE_STR: &str = "http://www.w3.org/2001/XMLSchema#double";
 //const DECIMAL_STR: &str = "http://www.w3.org/2001/XMLSchema#decimal";
 
-impl SerializeTrait for ValueSetValue {
+impl Serialize for ValueSetValue {
     fn serialize<S>(&self, serializer: S) -> result::Result<S::Ok, S::Error>
     where
         S: Serializer,
@@ -218,7 +217,7 @@ impl SerializeTrait for ValueSetValue {
             ValueSetValue::Language { language_tag } => {
                 let mut map = serializer.serialize_map(Some(2))?;
                 map.serialize_entry("type", "Language")?;
-                map.serialize_entry("languageTag", &language_tag.value())?;
+                map.serialize_entry("languageTag", &language_tag)?;
                 map.end()
             }
             ValueSetValue::IriStem { stem } => {
@@ -237,7 +236,7 @@ impl SerializeTrait for ValueSetValue {
             ValueSetValue::LanguageStem { stem } => {
                 let mut map = serializer.serialize_map(Some(2))?;
                 map.serialize_entry("type", "LanguageStem")?;
-                map.serialize_entry("stem", &stem.value())?;
+                map.serialize_entry("stem", &stem)?;
                 map.end()
             }
             ValueSetValue::LanguageStemRange { stem, exclusions } => {
@@ -371,7 +370,7 @@ impl<'de> Deserialize<'de> for Stem {
             {
                 struct FieldVisitor;
 
-                impl<'de> Visitor<'de> for FieldVisitor {
+                impl Visitor<'_> for FieldVisitor {
                     type Value = Field;
 
                     fn expecting(&self, formatter: &mut fmt::Formatter) -> fmt::Result {
@@ -486,7 +485,7 @@ impl<'de> Deserialize<'de> for ValueSetValue {
             {
                 struct FieldVisitor;
 
-                impl<'de> Visitor<'de> for FieldVisitor {
+                impl Visitor<'_> for FieldVisitor {
                     type Value = Field;
 
                     fn expecting(&self, formatter: &mut fmt::Formatter) -> fmt::Result {
@@ -675,14 +674,14 @@ impl<'de> Deserialize<'de> for ValueSetValue {
                                 ))
                             })?;
                             Ok(ValueSetValue::LanguageStem {
-                                stem: Lang::new(&stem),
+                                stem: Lang::new_unchecked(stem),
                             })
                         }
                         None => Err(de::Error::missing_field("stem")),
                     },
                     Some(ValueSetValueType::Language) => match language_tag {
                         Some(language_tag) => Ok(ValueSetValue::Language {
-                            language_tag: Lang::new(language_tag.as_str()),
+                            language_tag: Lang::new_unchecked(language_tag),
                         }),
                         None => Err(de::Error::missing_field("languageTag")),
                     },
@@ -743,9 +742,9 @@ impl<'de> Deserialize<'de> for ValueSetValue {
                     Some(ValueSetValueType::Other(iri)) => match value {
                         Some(v) => match language_tag {
                             Some(lang) => Ok(ValueSetValue::ObjectValue(ObjectValue::Literal(
-                                Literal::StringLiteral {
+                                SLiteral::StringLiteral {
                                     lexical_form: v,
-                                    lang: Some(Lang::new(&lang)),
+                                    lang: Some(Lang::new_unchecked(lang)),
                                 },
                             ))),
                             None => Ok(ValueSetValue::datatype_literal(&v, &iri)),
@@ -755,13 +754,13 @@ impl<'de> Deserialize<'de> for ValueSetValue {
                     None => match value {
                         Some(lexical_form) => match language {
                             Some(language) => Ok(ValueSetValue::ObjectValue(ObjectValue::Literal(
-                                Literal::StringLiteral {
+                                SLiteral::StringLiteral {
                                     lexical_form,
-                                    lang: Some(Lang::new(&language)),
+                                    lang: Some(Lang::new_unchecked(language)),
                                 },
                             ))),
                             None => Ok(ValueSetValue::ObjectValue(ObjectValue::Literal(
-                                Literal::StringLiteral {
+                                SLiteral::StringLiteral {
                                     lexical_form,
                                     lang: None,
                                 },
