@@ -1,13 +1,14 @@
 use iri_s::IriS;
 use rbe::Value;
 use serde::Serialize;
+use srdf::literal::SLiteral;
 use srdf::numeric_literal::NumericLiteral;
 use srdf::Object;
 use std::fmt::Display;
 
 impl Value for Node {}
 
-#[derive(PartialEq, Eq, Hash, Debug, Default, Clone, Serialize)]
+#[derive(PartialEq, Eq, Hash, Debug, Default, Clone)]
 pub struct Node {
     node: Object,
 }
@@ -33,6 +34,12 @@ impl Node {
     pub fn as_object(&self) -> &Object {
         &self.node
     }
+
+    pub fn literal(lit: SLiteral) -> Node {
+        Node {
+            node: Object::literal(lit),
+        }
+    }
 }
 
 impl Display for Node {
@@ -52,3 +59,12 @@ impl From<IriS> for Node {
         Node { node: iri.into() }
     }
 }
+
+impl Serialize for Node {
+    fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
+    where
+        S: serde::Serializer,
+    {
+        self.node.serialize(serializer)
+    }
+}
