@@ -47,7 +47,7 @@ impl ShapeMapParser<'_> {
                         node_selector,
                         shape_selector,
                     } => {
-                        tracing::debug!("Association {node_selector:?}@{shape_selector:?}");
+                        // tracing::debug!("Association {node_selector:?}@{shape_selector:?}");
                         query_shapemap.add_association(node_selector, shape_selector);
                     }
                 }
@@ -123,7 +123,7 @@ impl ShapeMapStatementIterator<'_> {
             }),
             Err(Err::Incomplete(_)) => Ok(ShapeMapStatementIterator { src, done: false }),
             Err(e) => Err(ParseError::Custom {
-                msg: format!("cannot start parsing. Error: {}", e),
+                msg: format!("cannot start parsing. Error: {e}"),
             }),
         }
     }
