@@ -215,13 +215,19 @@ impl<'de> Deserialize<'de> for NumericLiteral {
 impl Display for NumericLiteral {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         match self {
-            NumericLiteral::Double(d) => write!(f, "{}", d),
-            NumericLiteral::Integer(n) => write!(f, "{}", n),
-            NumericLiteral::Decimal(d) => write!(f, "{}", d),
+            NumericLiteral::Double(d) => write!(f, "{d}"),
+            NumericLiteral::Integer(n) => write!(f, "{n}"),
+            NumericLiteral::Decimal(d) => write!(f, "{d}"),
         }
     }
 }
 
+impl PartialOrd for NumericLiteral {
+    fn partial_cmp(&self, other: &Self) -> Option<std::cmp::Ordering> {
+        Some(self.as_decimal().partial_cmp(&other.as_decimal()).unwrap())
+    }
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
