@@ -1,21 +1,19 @@
-use std::{
-    convert::Infallible,
-    fmt::{Debug, Display},
-};
+use std::fmt::{Debug, Display};
 
-use crate::literal::Literal;
+use crate::literal::SLiteral;
 use crate::numeric_literal::NumericLiteral;
+use crate::RDFError;
 use iri_s::IriS;
 use serde::{Deserialize, Serialize};
 
 /// Concrete representation of RDF objects which can be IRIs, Blank nodes or literals
 ///
-/// Note: We plan to support triple terms as in RDF-star in the future
+/// Note: We plan to support triple terms as in RDF-1.2 in the future
 #[derive(Clone, Hash, PartialEq, Eq, Serialize, Deserialize)]
 pub enum Object {
     Iri(IriS),
     BlankNode(String),
-    Literal(Literal),
+    Literal(SLiteral),
 }
 
 impl Object {
@@ -27,10 +25,14 @@ impl Object {
         Object::BlankNode(str)
     }
 
-    pub fn literal(lit: Literal) -> Object {
+    pub fn literal(lit: SLiteral) -> Object {
         Object::Literal(lit)
     }
 
+    pub fn str(str: &str) -> Object {
+        Object::Literal(SLiteral::str(str))
+    }
+
     pub fn length(&self) -> usize {
         match self {
             Object::Iri(iri) => iri.as_str().len(),
@@ -45,6 +47,10 @@ impl Object {
             Object::Literal(lit) => lit.numeric_value(),
         }
     }
+
+    pub fn boolean(b: bool) -> Object {
+        Object::Literal(SLiteral::boolean(b))
+    }
 }
 
 impl From<IriS> for Object {
@@ -53,8 +59,8 @@ impl From<IriS> for Object {
     }
 }
 
-impl From<Literal> for Object {
-    fn from(lit: Literal) -> Self {
+impl From<SLiteral> for Object {
+    fn from(lit: SLiteral) -> Self {
         Object::Literal(lit)
     }
 }
@@ -69,8 +75,9 @@ impl From<Object> for oxrdf::Term {
     }
 }
 
-impl From<oxrdf::Term> for Object {
+/*impl From<oxrdf::Term> for Object {
     fn from(value: oxrdf::Term) -> Self {
+        println!("Converting oxrdf::Term to Object: {value:?}");
         match value {
             oxrdf::Term::NamedNode(named_node) => Object::iri(IriS::from_named_node(&named_node)),
             oxrdf::Term::BlankNode(blank_node) => Object::bnode(blank_node.into_string()),
@@ -79,10 +86,31 @@ impl From<oxrdf::Term> for Object {
             oxrdf::Term::Triple(_) => todo!(),
         }
     }
+}*/
+
+impl TryFrom<oxrdf::Term> for Object {
+    // TODO: Change this to a more appropriate error type
+    type Error = RDFError;
+
+    fn try_from(value: oxrdf::Term) -> Result<Self, Self::Error> {
+        match value {
+            oxrdf::Term::NamedNode(named_node) => {
+                Ok(Object::iri(IriS::from_named_node(&named_node)))
+            }
+            oxrdf::Term::BlankNode(blank_node) => Ok(Object::bnode(blank_node.into_string())),
+            oxrdf::Term::Literal(literal) => {
+                let lit: SLiteral = literal.try_into()?;
+                Ok(Object::literal(lit))
+            }
+            #[cfg(feature = "rdf-star")]
+            oxrdf::Term::Triple(_) => todo!(),
+        }
+    }
 }
 
 impl TryFrom<Object> for oxrdf::Subject {
-    type Error = Infallible;
+    // TODO: Change this to a more appropriate error type
+    type Error = RDFError;
 
     fn try_from(value: Object) -> Result<Self, Self::Error> {
         match value {
@@ -118,3 +146,14 @@ impl Debug for Object {
         }
     }
 }
+
+impl PartialOrd for Object {
+    fn partial_cmp(&self, other: &Self) -> Option<std::cmp::Ordering> {
+        match (self, other) {
+            (Object::Iri(a), Object::Iri(b)) => a.partial_cmp(b),
+            (Object::BlankNode(a), Object::BlankNode(b)) => a.partial_cmp(b),
+            (Object::Literal(a), Object::Literal(b)) => a.partial_cmp(b),
+            _ => None,
+        }
+    }
+}
