@@ -8,10 +8,10 @@ use iri_s::IriS;
 use std::fmt::Debug;
 
 use crate::{
-    literal::Literal, matcher::Any, rdf_parser, FocusRDF, PResult, Query, RDFParseError, Rdf,
-    Triple, RDF_FIRST, RDF_NIL_STR, RDF_REST, RDF_TYPE,
+    matcher::Any, rdf_first, rdf_parser, rdf_rest, rdf_type, FocusRDF, NeighsRDF, Object, PResult,
+    RDFParseError, Rdf, Triple, RDF_NIL_STR,
 };
-use crate::{srdf_basic::Literal as _, Iri as _};
+use crate::{Iri as _, Literal as _};
 
 /// By implementing the `RDFNodeParse` trait a type says that it can be used to parse RDF data which have a focus node.
 /// RDF data with a focus node have to implement the [`FocusRDF`] trait.
@@ -25,11 +25,15 @@ pub trait RDFNodeParse<RDF: FocusRDF> {
     #[inline(always)]
     fn parse(&mut self, node: &IriS, mut rdf: RDF) -> PResult<Self::Output> {
         let iri: RDF::IRI = node.clone().into();
-        let focus = iri.into();
+        let focus: RDF::Term = iri.into().into();
         rdf.set_focus(&focus);
         self.parse_impl(&mut rdf)
     }
 
+    /// Borrows a parser instead of consuming it.
+    ///
+    /// Used to apply parser combinators on `self` without losing ownership.
+    /// This is useful when you want to chain parsers or apply combinators without consuming the original parser.
     #[inline(always)]
     fn by_ref(&mut self) -> ByRef<'_, Self>
     where
@@ -320,14 +324,19 @@ where
     }
 }
 
-pub fn and_then<RDF, P, F, O, E>(parser: P, function: F) -> AndThen<P, F>
+///  Applies a function `func` on the result of a parser, which may fail with an error.
+///
+pub fn and_then<RDF, P, F, O, E>(parser: P, func: F) -> AndThen<P, F>
 where
     RDF: FocusRDF,
     P: RDFNodeParse<RDF>,
     F: FnMut(P::Output) -> Result<O, E>,
     E: Into<RDFParseError>,
 {
-    AndThen { parser, function }
+    AndThen {
+        parser,
+        function: func,
+    }
 }
 
 #[derive(Copy, Clone)]
@@ -608,53 +617,43 @@ where
     }
 }
 
-/// Checks if the focus node is an IRI
-/// ```
-/// use iri_s::{IriS, iri};
-/// use srdf::{SRDFGraph, iri, RDFNodeParse};
+/// Creates a parser that returns the current focus node as an Object
 ///
-/// let graph = SRDFGraph::new();
-/// let x = iri!("http://example.org/x");
-/// assert_eq!(iri().parse(&x, graph).unwrap(), x)
-/// ```
-pub fn iri<R>() -> impl RDFNodeParse<R, Output = IriS>
+pub fn object<RDF>() -> ParseObject<RDF>
 where
-    R: FocusRDF,
+    RDF: FocusRDF,
 {
-    // TODO: this clone can be removed as it is only necessary because of the error
-    //       and the error can be propagated from the try_into
-    term().flat_map(|t: R::Term| {
-        let iri: R::IRI = t
-            .clone()
-            .try_into()
-            .map_err(|_| RDFParseError::ExpectedIRI {
-                term: format!("{t}"),
-            })?;
-        let iri_string = iri.as_str();
-        Ok(iri!(iri_string))
-    })
+    ParseObject {
+        _marker_rdf: PhantomData,
+    }
 }
 
-/// Checks if the focus node is an IRI
-/// ```
-/// use iri_s::{IriS, iri};
-/// use srdf::{SRDFGraph, iri, RDFNodeParse};
-///
-/// let graph = SRDFGraph::new();
-/// let x = iri!("http://example.org/x");
-/// assert_eq!(iri().parse(&x, graph).unwrap(), x)
-/// ```
-pub fn literal<RDF: FocusRDF>() -> impl RDFNodeParse<RDF, Output = Literal> {
-    term().flat_map(|ref t: RDF::Term| {
-        let literal: RDF::Literal =
-            t.clone()
-                .try_into()
-                .map_err(|_| RDFParseError::ExpectedLiteral {
-                    term: t.to_string(),
-                })?;
-        let literal: Literal = literal.as_literal();
-        Ok(literal)
-    })
+#[derive(Debug, Clone)]
+pub struct ParseObject<RDF> {
+    _marker_rdf: PhantomData<RDF>,
+}
+
+impl<RDF> RDFNodeParse<RDF> for ParseObject<RDF>
+where
+    RDF: FocusRDF,
+{
+    type Output = Object;
+
+    fn parse_impl(&mut self, rdf: &mut RDF) -> PResult<Object> {
+        match rdf.get_focus() {
+            Some(focus) => {
+                let object: Object =
+                    focus
+                        .clone()
+                        .try_into()
+                        .map_err(|_| RDFParseError::TermToRDFNodeFailed {
+                            term: focus.to_string(),
+                        })?;
+                Ok(object)
+            }
+            None => Err(RDFParseError::NoFocusNode),
+        }
+    }
 }
 
 /// Creates a parser that returns the current focus node as a term
@@ -688,6 +687,94 @@ where
     }
 }
 
+/// Creates a parser that returns the current focus node as a iri
+///
+/// ```
+/// use iri_s::{IriS, iri};
+/// use srdf::{SRDFGraph, iri, RDFNodeParse};
+///
+/// let graph = SRDFGraph::new();
+/// let x = iri!("http://example.org/x");
+/// assert_eq!(iri().parse(&x, graph).unwrap(), x)
+/// ```
+pub fn iri<RDF>() -> ParseIri<RDF>
+where
+    RDF: FocusRDF,
+{
+    ParseIri {
+        _marker_rdf: PhantomData,
+    }
+}
+
+#[derive(Debug, Clone)]
+pub struct ParseIri<RDF> {
+    _marker_rdf: PhantomData<RDF>,
+}
+
+impl<RDF> RDFNodeParse<RDF> for ParseIri<RDF>
+where
+    RDF: FocusRDF,
+{
+    type Output = RDF::IRI;
+
+    fn parse_impl(&mut self, rdf: &mut RDF) -> PResult<RDF::IRI> {
+        match rdf.get_focus() {
+            Some(focus) => {
+                let iri: RDF::IRI =
+                    RDF::term_as_iri(focus).map_err(|_| RDFParseError::ExpectedIRI {
+                        term: format!("{focus}"),
+                    })?;
+                Ok(iri)
+            }
+            None => Err(RDFParseError::NoFocusNode),
+        }
+    }
+}
+
+/// Creates a parser that returns the current focus node as a literal
+///
+/// ```
+/// use iri_s::{IriS, iri};
+/// use srdf::{SRDFGraph, iri, RDFNodeParse};
+///
+/// let graph = SRDFGraph::new();
+/// let x = iri!("http://example.org/x");
+/// assert_eq!(iri().parse(&x, graph).unwrap(), x)
+/// ```
+pub fn literal<RDF>() -> ParseLiteral<RDF>
+where
+    RDF: FocusRDF,
+{
+    ParseLiteral {
+        _marker_rdf: PhantomData,
+    }
+}
+
+#[derive(Debug, Clone)]
+pub struct ParseLiteral<RDF> {
+    _marker_rdf: PhantomData<RDF>,
+}
+
+impl<RDF> RDFNodeParse<RDF> for ParseLiteral<RDF>
+where
+    RDF: FocusRDF,
+{
+    type Output = RDF::Literal;
+
+    fn parse_impl(&mut self, rdf: &mut RDF) -> PResult<RDF::Literal> {
+        match rdf.get_focus() {
+            Some(focus) => {
+                let iri: RDF::Literal =
+                    RDF::term_as_literal(focus).map_err(|_| RDFParseError::ExpectedLiteral {
+                        term: format!("{focus}"),
+                    })?;
+                Ok(iri)
+            }
+            None => Err(RDFParseError::NoFocusNode),
+        }
+    }
+}
+
 /// Parses the RDF list linked from the value of property `prop` at focus node
 ///
 pub fn property_list<RDF>(prop: &IriS) -> impl RDFNodeParse<RDF, Output = Vec<RDF::Term>>
@@ -705,12 +792,10 @@ where
     R: FocusRDF,
 {
     property_value(prop).flat_map(|term: R::Term| {
-        let literal: R::Literal =
-            term.clone()
-                .try_into()
-                .map_err(|_| RDFParseError::ExpectedLiteral {
-                    term: format!("{term}"),
-                })?;
+        let literal: R::Literal = <R::Term as TryInto<R::Literal>>::try_into(term.clone())
+            .map_err(|_| RDFParseError::ExpectedLiteral {
+                term: format!("{term}"),
+            })?;
         literal
             .as_bool()
             .ok_or_else(|| RDFParseError::ExpectedBoolean {
@@ -725,7 +810,7 @@ where
 {
     satisfy(
         |term: &R::Term| {
-            let tmp: Result<R::IRI, _> = term.clone().try_into();
+            let tmp: Result<R::IRI, _> = <R::Term as TryInto<R::IRI>>::try_into(term.clone());
             match tmp {
                 Ok(iri) => iri.as_str() == RDF_NIL_STR,
                 Err(_) => false,
@@ -740,7 +825,7 @@ where
 /// The `predicate_name` argument is useful in case of failure to know which condition has failed
 pub fn satisfy<RDF, P>(predicate: P, predicate_name: &str) -> Satisfy<RDF, P>
 where
-    RDF: Query,
+    RDF: NeighsRDF,
     P: FnMut(&RDF::Term) -> bool,
 {
     Satisfy {
@@ -800,6 +885,46 @@ where
     })
 }
 
+/// Return the literal values of `property` for the focus node
+///
+/// If some value is not a literal it fails, if there is no value returns an empty set
+pub fn property_values_literal<RDF>(
+    property: &IriS,
+) -> impl RDFNodeParse<RDF, Output = Vec<RDF::Literal>>
+where
+    RDF: FocusRDF,
+{
+    property_values(property).flat_map(|values| {
+        let lits: Vec<_> = values
+            .iter()
+            .flat_map(|t| {
+                let lit: <RDF as Rdf>::Literal = term_to_literal::<RDF>(t)?;
+                Ok::<RDF::Literal, RDFParseError>(lit)
+            })
+            .collect();
+        Ok(lits)
+    })
+}
+
+/// Return the string values of `property` for the focus node
+///
+/// If some value is not an ``xsd:string` it fails, if there is no value returns an empty set
+pub fn property_values_string<RDF>(property: &IriS) -> impl RDFNodeParse<RDF, Output = Vec<String>>
+where
+    RDF: FocusRDF,
+{
+    property_values(property).flat_map(|values| {
+        let strs: Vec<_> = values
+            .iter()
+            .flat_map(|t| {
+                let i = term_to_string::<RDF>(t)?;
+                Ok::<String, RDFParseError>(i)
+            })
+            .collect();
+        Ok(strs)
+    })
+}
+
 /// Return the IRI values of `property` for the focus node
 ///
 /// If some value is not an IRI it fails, if there is no value returns an empty set
@@ -839,6 +964,58 @@ where
     })
 }
 
+/// Returns the values of `property` for the focus node converted to concrete objects
+///
+/// For some values, it can fail if there is an error converting the term to an `Object`.
+/// For example, if the term is something like `"x"^^xsd:integer` it will fail.
+/// If there is no value, it returns an empty set
+pub fn property_objects<RDF>(property: &IriS) -> impl RDFNodeParse<RDF, Output = HashSet<Object>>
+where
+    RDF: FocusRDF,
+{
+    property_values(property).flat_map(|values| {
+        let rs: Result<HashSet<Object>, RDFParseError> = values
+            .into_iter()
+            .map(|t: RDF::Term| {
+                let obj: Object = t.try_into().map_err(|_| RDFParseError::SRDFError {
+                    err: "Error converting term to object".to_string(),
+                })?;
+                Ok::<Object, RDFParseError>(obj)
+            })
+            .collect();
+        let objects = rs?;
+        Ok(objects)
+    })
+}
+
+/// Returns the values of `property` for the focus node as iris
+///
+/// If any of the values is not an IRI it fails
+/// If there is no value, it returns an empty set
+pub fn property_iris<RDF>(property: &IriS) -> impl RDFNodeParse<RDF, Output = HashSet<IriS>>
+where
+    RDF: FocusRDF,
+{
+    property_values(property).flat_map(|values| {
+        let rs: Result<HashSet<IriS>, RDFParseError> =
+            values.into_iter().map(value_to_iri::<RDF>).collect();
+        let iris = rs?;
+        Ok(iris)
+    })
+}
+
+fn value_to_iri<RDF>(value: RDF::Term) -> Result<IriS, RDFParseError>
+where
+    RDF: FocusRDF,
+{
+    let iri: IriS = RDF::term_as_iri(&value)
+        .map_err(|_| RDFParseError::ExpectedIRI {
+            term: format!("{value}"),
+        })?
+        .into();
+    Ok(iri)
+}
+
 /// Returns the values of `property` for the focus node
 ///
 /// If there is no value, it returns an empty set
@@ -880,7 +1057,7 @@ where
 /// It doesn't move the current focus node
 pub fn property_value<RDF>(property: &IriS) -> PropertyValue<RDF>
 where
-    RDF: Query,
+    RDF: NeighsRDF,
 {
     PropertyValue {
         property: property.clone(),
@@ -888,7 +1065,7 @@ where
     }
 }
 
-pub struct PropertyValue<RDF: Query> {
+pub struct PropertyValue<RDF: NeighsRDF> {
     property: IriS,
     _marker_rdf: PhantomData<RDF>,
 }
@@ -937,7 +1114,7 @@ where
 /// it shows the neighbourhood of the current node
 pub fn property_value_debug<RDF>(property: &IriS) -> PropertyValueDebug<RDF>
 where
-    RDF: Query,
+    RDF: NeighsRDF,
 {
     PropertyValueDebug {
         property: property.clone().into(),
@@ -945,7 +1122,7 @@ where
     }
 }
 
-pub struct PropertyValueDebug<RDF: Query> {
+pub struct PropertyValueDebug<RDF: NeighsRDF> {
     property: RDF::IRI,
     _marker_rdf: PhantomData<RDF>,
 }
@@ -999,14 +1176,14 @@ where
 /// it shows the neighbourhood of the current node
 pub fn neighs<RDF>() -> Neighs<RDF>
 where
-    RDF: Query,
+    RDF: NeighsRDF,
 {
     Neighs {
         _marker_rdf: PhantomData,
     }
 }
 
-pub struct Neighs<RDF: Query> {
+pub struct Neighs<RDF: NeighsRDF> {
     _marker_rdf: PhantomData<RDF>,
 }
 
@@ -1019,7 +1196,7 @@ where
     fn parse_impl(&mut self, rdf: &mut RDF) -> PResult<HashMap<RDF::IRI, HashSet<RDF::Term>>> {
         match rdf.get_focus() {
             Some(focus) => {
-                let subj = focus.clone().try_into().map_err(|_| {
+                let subj = RDF::term_as_subject(focus).map_err(|_| {
                     RDFParseError::ExpectedFocusAsSubject {
                         focus: focus.to_string(),
                     }
@@ -1097,16 +1274,29 @@ where
     Ok(ints)
 }
 
+fn term_to_literal<R>(term: &R::Term) -> Result<R::Literal, RDFParseError>
+where
+    R: Rdf,
+{
+    let literal: R::Literal =
+        <R::Term as TryInto<R::Literal>>::try_into(term.clone()).map_err(|_| {
+            RDFParseError::ExpectedLiteral {
+                term: format!("{term}"),
+            }
+        })?;
+    Ok(literal)
+}
+
 fn term_to_int<R>(term: &R::Term) -> Result<isize, RDFParseError>
 where
     R: Rdf,
 {
     let literal: R::Literal =
-        term.clone()
-            .try_into()
-            .map_err(|_| RDFParseError::ExpectedLiteral {
+        <R::Term as TryInto<R::Literal>>::try_into(term.clone()).map_err(|_| {
+            RDFParseError::ExpectedLiteral {
                 term: format!("{term}"),
-            })?;
+            }
+        })?;
     let n = literal
         .as_integer()
         .ok_or_else(|| RDFParseError::ExpectedInteger {
@@ -1119,12 +1309,11 @@ fn term_to_iri<R>(term: &R::Term) -> Result<IriS, RDFParseError>
 where
     R: Rdf,
 {
-    let iri: R::IRI = term
-        .clone() // TODO: this clone could be removed?
-        .try_into()
-        .map_err(|_| RDFParseError::ExpectedIRI {
+    let iri: R::IRI = <R::Term as TryInto<R::IRI>>::try_into(term.clone()).map_err(|_| {
+        RDFParseError::ExpectedIRI {
             term: format!("{term}"),
-        })?;
+        }
+    })?;
     let iri_string = iri.as_str();
     Ok(iri!(iri_string))
 }
@@ -1134,11 +1323,11 @@ where
     R: Rdf,
 {
     let literal: R::Literal =
-        term.clone()
-            .try_into()
-            .map_err(|_| RDFParseError::ExpectedLiteral {
+        <R::Term as TryInto<R::Literal>>::try_into(term.clone()).map_err(|_| {
+            RDFParseError::ExpectedLiteral {
                 term: format!("{term}"),
-            })?;
+            }
+        })?;
     Ok(literal.lexical_form().to_string())
 }
 
@@ -1181,6 +1370,70 @@ where
     }
 }
 
+/// Combines the results of parsers that return vectors of values
+///
+pub fn combine_parsers_vec<RDF, P, A>(parsers: Vec<P>) -> CombineParsers<P>
+where
+    RDF: FocusRDF,
+    P: RDFNodeParse<RDF, Output = Vec<A>>,
+{
+    CombineParsers { parsers }
+}
+
+pub struct CombineParsers<P> {
+    parsers: Vec<P>,
+}
+
+impl<RDF, P, A> RDFNodeParse<RDF> for CombineParsers<P>
+where
+    RDF: FocusRDF,
+    P: RDFNodeParse<RDF, Output = Vec<A>>,
+{
+    type Output = Vec<A>;
+
+    fn parse_impl(&mut self, rdf: &mut RDF) -> PResult<Vec<A>> {
+        let mut result = Vec::new();
+        for p in self.parsers.iter_mut() {
+            match p.parse_impl(rdf) {
+                Err(e) => return Err(e),
+                Ok(vs) => {
+                    result.extend(vs);
+                }
+            }
+        }
+        Ok(result)
+    }
+}
+
+pub fn opaque<RDF, F, O>(f: F) -> Opaque<F, RDF, O>
+where
+    RDF: FocusRDF,
+    F: FnMut(&mut dyn FnMut(&mut dyn RDFNodeParse<RDF, Output = O>)),
+{
+    Opaque(f, PhantomData)
+}
+
+#[derive(Copy, Clone)]
+pub struct Opaque<F, RDF, O>(F, PhantomData<fn(&mut RDF) -> O>);
+
+impl<RDF, F, O> RDFNodeParse<RDF> for Opaque<F, RDF, O>
+where
+    RDF: FocusRDF,
+    F: FnMut(&mut dyn FnMut(&mut dyn RDFNodeParse<RDF, Output = O>)),
+{
+    type Output = O;
+
+    fn parse_impl(&mut self, rdf: &mut RDF) -> PResult<Self::Output> {
+        let mut result = Err(RDFParseError::Custom {
+            msg: "Opaque parser failed".to_string(),
+        });
+        (self.0)(&mut |parser| {
+            result = parser.parse_impl(rdf);
+        });
+        result
+    }
+}
+
 /// Parses a node as a bool
 ///
 pub fn bool<R>() -> impl RDFNodeParse<R, Output = bool>
@@ -1188,12 +1441,10 @@ where
     R: FocusRDF,
 {
     get_focus().flat_map(|term: R::Term| {
-        let literal: R::Literal =
-            term.clone()
-                .try_into()
-                .map_err(|_| RDFParseError::ExpectedLiteral {
-                    term: format!("{term}"),
-                })?;
+        let literal: R::Literal = <R::Term as TryInto<R::Literal>>::try_into(term.clone())
+            .map_err(|_| RDFParseError::ExpectedLiteral {
+                term: format!("{term}"),
+            })?;
         let boolean = literal
             .as_bool()
             .ok_or_else(|| RDFParseError::ExpectedInteger {
@@ -1225,7 +1476,7 @@ where
 /// ```
 pub fn rdf_list<RDF>() -> RDFList<RDF>
 where
-    RDF: Query,
+    RDF: NeighsRDF,
 {
     RDFList {
         _marker_rdf: PhantomData,
@@ -1296,7 +1547,7 @@ where
     }
 }
 
-pub struct RDFList<RDF: Query> {
+pub struct RDFList<RDF: NeighsRDF> {
     _marker_rdf: PhantomData<RDF>,
 }
 
@@ -1330,7 +1581,7 @@ where
 /// Parses a node as an RDF List applying each element of the list a parser
 pub fn parse_rdf_list<RDF, P>(parser: P) -> ParseRDFList<P>
 where
-    RDF: Query,
+    RDF: NeighsRDF,
 {
     ParseRDFList { parser }
 }
@@ -1377,8 +1628,8 @@ where
     if node_is_rdf_nil::<RDF>(focus) {
         Ok(Vec::new())
     } else {
-        let value = property_value(&RDF_FIRST).parse_impl(rdf)?;
-        let rest = property_value(&RDF_REST).parse_impl(rdf)?;
+        let value = property_value(rdf_first()).parse_impl(rdf)?;
+        let rest = property_value(rdf_rest()).parse_impl(rdf)?;
         if visited.contains(&rest) {
             Err(RDFParseError::RecursiveRDFList {
                 node: format!("{rest}"),
@@ -1395,9 +1646,9 @@ where
 
 fn node_is_rdf_nil<R>(node: &R::Term) -> bool
 where
-    R: Query,
+    R: NeighsRDF,
 {
-    let tmp: Result<R::IRI, _> = node.clone().try_into();
+    let tmp: Result<R::IRI, _> = <R::Term as TryInto<R::IRI>>::try_into(node.clone());
     match tmp {
         Ok(iri) => iri.as_str() == RDF_NIL_STR,
         Err(_) => false,
@@ -1413,7 +1664,7 @@ where
     satisfy(
         // TODO: this clone can be removed
         move |node: &RDF::Term| {
-            let tmp: Result<RDF::IRI, _> = node.clone().try_into();
+            let tmp: Result<RDF::IRI, _> = <RDF::Term as TryInto<RDF::IRI>>::try_into(node.clone());
             match tmp {
                 Ok(iri) => iri.as_str() == expected_iri.as_str(),
                 Err(_) => false,
@@ -1479,11 +1730,11 @@ where
     RDF: FocusRDF,
 {
     apply(term, |term| {
-        let iri: RDF::IRI = term
-            .clone()
-            .try_into()
-            .map_err(|_| RDFParseError::ExpectedIRI {
-                term: format!("{term}"),
+        let iri: RDF::IRI =
+            <RDF::Term as TryInto<RDF::IRI>>::try_into(term.clone()).map_err(|_| {
+                RDFParseError::ExpectedIRI {
+                    term: format!("{term}"),
+                }
             })?;
         let iri_string = iri.as_str();
         Ok(iri!(iri_string))
@@ -1675,14 +1926,14 @@ pub fn instances_of<RDF>(expected: &IriS) -> impl RDFNodeParse<RDF, Output = Vec
 where
     RDF: FocusRDF,
 {
-    subjects_with_property_value::<RDF>(&RDF_TYPE, &expected.clone().into())
+    subjects_with_property_value::<RDF>(rdf_type(), &expected.clone().into())
 }
 
 pub fn parse_rdf_type<RDF>() -> impl RDFNodeParse<RDF, Output = RDF::Term>
 where
     RDF: FocusRDF,
 {
-    property_value(&RDF_TYPE)
+    property_value(rdf_type())
 }
 
 pub fn has_type<RDF>(expected: IriS) -> impl RDFNodeParse<RDF, Output = ()>
@@ -1700,7 +1951,7 @@ where
     cond(
         &term,
         move |t| t == &expected,
-        format!("Term {term} not equals {}", expected_str),
+        format!("Term {term} not equals {expected_str}"),
     )
 }
 
@@ -1719,7 +1970,7 @@ where
     }
 }
 
-pub struct SubjectsPropertyValue<RDF: Query> {
+pub struct SubjectsPropertyValue<RDF: NeighsRDF> {
     property: RDF::IRI,
     value: RDF::Term,
     _marker_rdf: PhantomData<RDF>,
@@ -1784,12 +2035,11 @@ where
     fn parse_impl(&mut self, rdf: &mut RDF) -> PResult<Self::Output> {
         let rdf_type = parse_rdf_type().parse_impl(rdf)?;
         let iri: RDF::IRI =
-            rdf_type
-                .clone()
-                .try_into()
-                .map_err(|_| RDFParseError::ExpectedIRI {
+            <RDF::Term as TryInto<RDF::IRI>>::try_into(rdf_type.clone()).map_err(|_| {
+                RDFParseError::ExpectedIRI {
                     term: format!("{rdf_type}"),
-                })?;
+                }
+            })?;
         let iri_string = iri.as_str();
         match self.values.get_mut(&iri!(iri_string)) {
             Some(p) => p.parse_impl(rdf),
@@ -1838,6 +2088,8 @@ where
 
 /// Applies a parser over a list of nodes and returns the list of values
 ///
+/// Moves the focus to each node in the list and applies the parser to it.
+/// Returns a vector of results of each parser
 pub fn parse_nodes<RDF, P>(nodes: Vec<RDF::Term>, parser: P) -> ParserNodes<RDF, P>
 where
     RDF: FocusRDF,
@@ -1846,6 +2098,47 @@ where
     ParserNodes { nodes, parser }
 }
 
+pub fn parse_property_values<RDF, P>(property: &IriS, parser: P) -> ParserPropertyValues<RDF, P>
+where
+    RDF: FocusRDF,
+    P: RDFNodeParse<RDF>,
+{
+    ParserPropertyValues {
+        property: property.clone(),
+        parser,
+        _marker_rdf: PhantomData,
+    }
+}
+
+#[derive(Debug, Clone)]
+pub struct ParserPropertyValues<RDF, P>
+where
+    RDF: FocusRDF,
+{
+    property: IriS,
+    parser: P,
+    _marker_rdf: PhantomData<RDF>,
+}
+
+impl<RDF, A, P> RDFNodeParse<RDF> for ParserPropertyValues<RDF, P>
+where
+    RDF: FocusRDF,
+    P: RDFNodeParse<RDF, Output = A>,
+{
+    type Output = Vec<A>;
+
+    fn parse_impl(&mut self, rdf: &mut RDF) -> PResult<Self::Output> {
+        let values = property_values(&self.property).parse_impl(rdf)?;
+        let mut results = Vec::new();
+        for node in values.iter() {
+            rdf.set_focus(node);
+            let value = self.parser.parse_impl(rdf)?;
+            results.push(value)
+        }
+        Ok(results)
+    }
+}
+
 #[derive(Clone)]
 pub struct ParserNodes<RDF, P>
 where
